TYPESCRIPT_TRANSLATION = {
    "AutoField": "number",
    "BigAutoField": "number",
    "BigIntegerField": "number",
    "BinaryField": "number",
    "BooleanField": "boolean",
    "CharField": "text",
    "CommaSeparatedIntegerField": "number",
    "DateField": "Date",
    "DateTimeField": "Date",
    "DecimalField": "number",
    "DurationField": "number",
    "EmailField": "text",
    "FilePathField": "text",
    "FloatField": "number",
    "GenericIPAddressField": "text",
    "IPAddressField": "text",
    "IntegerField": "number",
    "NullBooleanField": "boolean | null",
    "PositiveBigIntegerField": "number",
    "PositiveIntegerField": "number",
    "PositiveSmallIntegerField": "number",
    "SlugField": "string",
    "SmallAutoField": "number",
    "SmallIntegerField": "number",
    "TextField": "string",
    "TimeField": "string",
    "URLField": "string",
    "UUIDField": "string",
    "ForeignKey": "number",
    "OneToOneField": "number",
}

FORM_TRANSLATION = {
    "AutoField": "<input value='%s' type='number' name='%s' />",
    "BigAutoField": "<input value='%s' type='number' name='%s' />",
    "BigIntegerField": "<input value='%s' type='number' name='%s' />",
    "BinaryField": "<input value='%s' type='number' name='%s' />",
    "BooleanField": "<input value='%s' type='checkbox' name='%s' />",
    "CharField": "<input value='%s' name='%s'/>",
    "CommaSeparatedIntegerField": ("<input value='%s' type='number' name='%s' />"),
    "DateField": "<input value='%s' type='date' name='%s'/>",
    "DateTimeField": "<input value='%s' type='date' name='%s'/>",
    "DecimalField": "<input value='%s' type='number' name='%s' />",
    "DurationField": "<input value='%s' type='number' name='%s' />",
    "EmailField": "<input value='%s' name='%s'/>",
    "FilePathField": "<input value='%s' name='%s'/>",
    "FloatField": "<input value='%s' type='number' name='%s' />",
    "GenericIPAddressField": "<input value='%s' name='%s'/>",
    "IPAddressField": "<input value='%s' name='%s'/>",
    "IntegerField": "<input value='%s' type='number' name='%s' />",
    "NullBooleanField": "<input value='%s' type='checkbox' name='%s' />",
    "PositiveBigIntegerField": "<input value='%s' type='number' name='%s' />",
    "PositiveIntegerField": "<input value='%s' type='number' name='%s' />",
    "PositiveSmallIntegerField": ("<input value='%s' type='number' name='%s' />"),
    "SlugField": "<input value='%s' name='%s' />",
    "SmallAutoField": "<input value='%s' type='number' name='%s' />",
    "SmallIntegerField": "<input value='%s' type='number' name='%s' />",
    "TextField": "<input value='%s' type='text' name='%s' />",
    "TimeField": "<input value='%s' name='%s' />",
    "URLField": "<input value='%s' name='%s' />",
    "UUIDField": "<input value='%s' name='%s' />",
    "ForeignKey": "<input value='%s' type='number' name='%s' />",
    "OneToOneField": "<input value='%s' type='number' name='%s' />",
}
